# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2020-02-26 15:03
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0005_auto_20200210_1644'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='societe',
            options={},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2020-02-28 16:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0007_societe_logo2'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='societe',
            name='logo2',
        ),
        migrations.AlterField(
            model_name='societe',
            name='logo',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Logo'),
        ),
    ]



# Generated by Django 2.2.19 on 2021-05-11 15:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0012_auto_20210511_1652'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='activity',
            options={},
        ),
        migrations.AlterField(
            model_name='activity',
            name='name',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Forme alternative d’activité'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='name',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Nom de la société'),
        ),
    ]



from django.conf import settings
from django.core.mail import send_mail
from django.db import models
from djangoldp.models import Model
from django.db.models.signals import post_save
from django.dispatch import receiver
from django.template import loader

class CompanyType(Model) :
    name = models.CharField(max_length=250, blank=True, null=True, verbose_name="Forme alternative d’activité")

    def __str__(self):
        return self.name

    class Meta:
        anonymous_perms = ['view']
        authenticated_perms = ['inherit', 'add', 'change']

class Societe(Model) :
    name = models.CharField(max_length=250, blank=True, null=True, verbose_name="Nom de la société")
    logo = models.CharField(max_length=250, blank=True, null=True, verbose_name="Logo")
    activity = models.ForeignKey(CompanyType, blank=True, null=True, verbose_name="Forme alternative d’activité", on_delete=models.SET_NULL, related_name='company_activity')
    siren = models.CharField(max_length=15, blank=True, null=True, verbose_name="Numéro de SIREN")
    address = models.CharField(max_length=250, blank=True, null=True, verbose_name="Adresse")
    postcode = models.CharField(max_length=5, blank=True, null=True, verbose_name="Code Postal")
    city = models.CharField(max_length=30, blank=True, null=True, verbose_name="Ville")
    dpt = models.CharField(max_length=3, blank=True, null=True, verbose_name="Département")
    website = models.CharField(max_length=250, blank=True, null=True, verbose_name="Site web")
    mail = models.CharField(max_length=50, blank=True, null=True, verbose_name="Adresse mail")
    phone = models.CharField(max_length=20, blank=True, null=True, verbose_name="Numéro de téléphone")
    lat = models.DecimalField(max_digits=15, decimal_places=12, blank=True, null=True, verbose_name="Lattitude")
    lng = models.DecimalField(max_digits=15, decimal_places=12, blank=True, null=True, verbose_name="Longitude") 
    peps = models.BooleanField(default="False", blank=True,verbose_name="PEPS")

    def __str__(self):
        return self.name

    class Meta:
        anonymous_perms = ['view']
        authenticated_perms = ['inherit', 'add', 'change'] 


from django.conf import settings
from django.conf.urls import url
from django.views.decorators.csrf import csrf_exempt
from .views import XLSXExportView

urlpatterns = [
    url(r'^societes/xlsx/$', csrf_exempt(XLSXExportView.as_view()), name='societes-xlsx'),
]


# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2020-03-05 10:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0008_auto_20200228_1709'),
    ]

    operations = [
        migrations.AlterField(
            model_name='societe',
            name='lat',
            field=models.DecimalField(blank=True, decimal_places=12, max_digits=15, null=True, verbose_name='Lattitude'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='lng',
            field=models.DecimalField(blank=True, decimal_places=12, max_digits=15, null=True, verbose_name='Longitude'),
        ),
    ]



from django.shortcuts import render
from django.http import HttpResponse
import csv

from djangoldp.models import Model
from djangoldp.views import NoCSRFAuthentication
from rest_framework.response import Response 
from rest_framework.views import APIView
from django.http import HttpResponseNotFound

from openpyxl import load_workbook
import validators
import io
import os.path

PACKAGE_PATH = os.path.realpath(os.path.dirname(__file__))

class XLSXExportView(APIView):
    # authentication_classes = (NoCSRFAuthentication,)

    def dispatch(self, request, *args, **kwargs):
        '''overriden dispatch method to append some custom headers'''
        response = super(XLSXExportView, self).dispatch(request, *args, **kwargs)
        response["Access-Control-Allow-Origin"] = request.META.get('HTTP_ORIGIN')
        response["Access-Control-Allow-Methods"] = "POST"
        response["Access-Control-Allow-Headers"] = "authorization, Content-Type, if-match, accept, cache-control, pragma, user-agent"
        response["Access-Control-Expose-Headers"] = "Location, User"
        response["Access-Control-Allow-Credentials"] = 'true'
        response["Accept-Post"] = "*/*"
        response["Accept"] = "*/*"
        return response

    def post(self, request):
        # Check that we get an array
        if (request.method == 'POST' and request.data and isinstance(request.data, list)):

            # Open the template file located in templates/export/
            templateFile = load_workbook(os.path.join(PACKAGE_PATH, 'templates/export/template.xlsx'))
            destFile = 'export_societes.xlsx'
            activeWorksheet = templateFile.active

            # Just make sure you can start writing at line 8 column 2
            rowNumber = 8
            columnNumber = 2

            for urlid in request.data:
              # Check that the array entries are URLs
              if validators.url(urlid):
                # Check that the corresponding Actors exists
                model, instance = Model.resolve(urlid)
                if instance and instance.activity:
                  # Generate XLSX file using the lib, see the lib readme
                  if instance.siren:
                    siren = instance.siren
                  else:
                    siren = "N/A"
                  
                  if instance.website:
                    website = instance.website
                  else:
                    website = "N/A"

                  if instance.mail:
                    mail = instance.mail
                  else:
                    mail = "N/A"

                  if instance.phone:
                    phone = instance.phone
                  else:
                    phone = "N/A"

                  activeWorksheet.cell(rowNumber, columnNumber, value=instance.name)
                  activeWorksheet.cell(rowNumber, columnNumber + 1, value=instance.activity.name)
                  activeWorksheet.cell(rowNumber, columnNumber + 2, value=siren)
                  activeWorksheet.cell(rowNumber, columnNumber + 3, value=instance.address)
                  activeWorksheet.cell(rowNumber, columnNumber + 4, value=instance.postcode)
                  activeWorksheet.cell(rowNumber, columnNumber + 5, value=instance.city)
                  activeWorksheet.cell(rowNumber, columnNumber + 6, value=website)
                  activeWorksheet.cell(rowNumber, columnNumber + 7, value=mail)
                  activeWorksheet.cell(rowNumber, columnNumber + 8, value=phone)
                  rowNumber += 1
            
            templateFile.save(destFile)
            try:
                from django.http import FileResponse
                response = FileResponse(io.open(destFile, mode="rb"))
                response['Content-Disposition'] = 'attachment; filename=' + destFile
                return response
            except IOError:
                # handle the case where file does not exist
                response = HttpResponseNotFound('<h1>File does not exist</h1>')

        return Response(status=204)




# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-02-10 15:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0004_auto_20200210_1440'),
    ]

    operations = [
        migrations.RenameField(
            model_name='societe',
            old_name='adress',
            new_name='address',
        ),
    ]



# Generated by Django 2.2.19 on 2021-05-11 15:26

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0013_auto_20210511_1716'),
    ]

    operations = [
        migrations.AlterField(
            model_name='societe',
            name='activity',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='company_activity', to='faabrickmap_data.Activity', verbose_name='Forme alternative d’activité'),
        ),
    ]



# Generated by Django 2.2.19 on 2021-05-11 14:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0011_societe_dpt'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='activity',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AddField(
            model_name='activity',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='activity',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AddField(
            model_name='societe',
            name='allow_create_backlink',
            field=models.BooleanField(default=True, help_text='set to False to disable backlink creation after Model save'),
        ),
        migrations.AddField(
            model_name='societe',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='activity',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='faabrickmap_data.Activity', verbose_name='Forme alternative d’activité'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='peps',
            field=models.BooleanField(blank=True, default='False', verbose_name='PEPS'),
        ),
    ]



# Generated by Django 2.2.19 on 2021-05-11 18:35

from django.db import migrations


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        ('faabrickmap_data', '0014_auto_20210511_1726'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Activity',
            new_name='CompanyType',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-01-30 20:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Activity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('name', models.CharField(max_length=250, verbose_name='Forme alternative d’activité')),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
        migrations.AddField(
            model_name='societe',
            name='adress',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Adresse'),
        ),
        migrations.AddField(
            model_name='societe',
            name='city',
            field=models.CharField(blank=True, max_length=15, null=True, verbose_name='Ville'),
        ),
        migrations.AddField(
            model_name='societe',
            name='lat',
            field=models.CharField(blank=True, max_length=25, null=True, verbose_name='Lattitude'),
        ),
        migrations.AddField(
            model_name='societe',
            name='lng',
            field=models.CharField(blank=True, max_length=25, null=True, verbose_name='Longitude'),
        ),
        migrations.AddField(
            model_name='societe',
            name='postcode',
            field=models.CharField(blank=True, max_length=5, null=True, verbose_name='Code Postal'),
        ),
        migrations.AddField(
            model_name='societe',
            name='siren',
            field=models.CharField(blank=True, max_length=15, null=True, verbose_name='Numéro de SIREN'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='logo',
            field=models.ImageField(blank=True, null=True, upload_to='', verbose_name='Logo'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='name',
            field=models.CharField(max_length=250, verbose_name='Nom de la société'),
        ),
        migrations.AlterField(
            model_name='societe',
            name='website',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Site web'),
        ),
        migrations.AddField(
            model_name='societe',
            name='activity',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='faabrickmap_data.Activity', verbose_name='Forme alternative d’activité'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-02-10 09:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('faabrickmap_data', '0002_auto_20200130_2128'),
    ]

    operations = [
        migrations.AddField(
            model_name='societe',
            name='mail',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Adresse mail'),
        ),
        migrations.AddField(
            model_name='societe',
            name='peps',
            field=models.BooleanField(default='False', verbose_name='PEPS'),
        ),
        migrations.AddField(
            model_name='societe',
            name='phone',
            field=models.CharField(blank=True, max_length=12, null=True, verbose_name='Numéro de téléphone'),
        ),
    ]
